@@ -1,8 +1,8 @@
-# video.py
+
 
 
 def process_video(file_path, table_name):
-    # implement with moon dream
+    
     import cv2
     import base64
 
@@ -18,11 +18,11 @@ def process_video(file_path, table_name):
             if not ret:
                 break
 
-            # Process every nth frame (adjust n as needed for performance)
-            n = 10  # Process every 10th frame
-        #video.release()
+            
+            n = 10  
+        
         return embeddings, texts
 
     except Exception as e:
         print(f"Error processing video: {e}")
-        return [], []  # Return empty lists in case of error
+        return [], []  
